# DiagramBot

![PyPI version](https://img.shields.io/pypi/v/diagrambot.svg)
[![Documentation Status](https://readthedocs.org/projects/diagrambot/badge/?version=latest)](https://diagrambot.readthedocs.io/en/latest/?version=latest)

DiagramBot generates great diagrams for your blog posts.

* PyPI package: https://pypi.org/project/diagrambot/
* Free software: MIT License
* Documentation: https://diagrambot.readthedocs.io.

## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyfeldroy/cookiecutter) and the [audreyfeldroy/cookiecutter-pypackage](https://github.com/audreyfeldroy/cookiecutter-pypackage) project template.
